@@ -40,9 +40,11 @@ private:
     KComboBox *cPreferredOggVorbisExtension;
     KIntSpinBox *iUpdateDelay;
     QCheckBox *cUseVFATNames;
+    QCheckBox *cWriteLogFiles;
     QCheckBox *cRemoveFailedFiles;
     QCheckBox *cUseSharedMemoryForTempFiles;
     KIntSpinBox *iMaxSizeForSharedMemoryTempFiles;
+    QCheckBox *cUsePipes;
 
     Config *config;
 
