@@ -19,7 +19,6 @@
 #include <KPushButton>
 #include <KFileDialog>
 #include <KIntSpinBox>
-#include <KStandardDirs>
 
 #include <QLayout>
 #include <QLabel>
@@ -63,7 +62,7 @@ ConfigGeneralPage::ConfigGeneralPage( Config *_config, QWidget *parent )
     sDefaultProfile += i18n("High");
     sDefaultProfile += i18n("Very high");
     sDefaultProfile += i18n("Lossless");
-    sDefaultProfile += i18n("Hybrid");
+//     sDefaultProfile += i18n("Hybrid"); // currently unused
     sDefaultProfile += config->customProfiles();
     cDefaultProfile->addItems( sDefaultProfile );
     cDefaultProfile->setCurrentIndex( cDefaultProfile->findText(config->data.general.defaultProfile) );
@@ -124,16 +123,15 @@ ConfigGeneralPage::ConfigGeneralPage( Config *_config, QWidget *parent )
 
     box->addSpacing( 5 );
 
-//     QHBoxLayout *waitForAlbumGainBox = new QHBoxLayout( 0 );
-//     box->addLayout( waitForAlbumGainBox );
+    QHBoxLayout *waitForAlbumGainBox = new QHBoxLayout( 0 );
+    box->addLayout( waitForAlbumGainBox );
     cWaitForAlbumGain = new QCheckBox( i18n("Apply album gain to converted files"), this );
     cWaitForAlbumGain->setToolTip( i18n("Keep songs of the same album waiting in file list in order to apply album gain to all files.") );
     cWaitForAlbumGain->setChecked( config->data.general.waitForAlbumGain );
-    cWaitForAlbumGain->hide();
-//     waitForAlbumGainBox->addWidget( cWaitForAlbumGain );
-//     connect( cWaitForAlbumGain, SIGNAL(toggled(bool)), this, SIGNAL(configChanged()) );
+    waitForAlbumGainBox->addWidget( cWaitForAlbumGain );
+    connect( cWaitForAlbumGain, SIGNAL(toggled(bool)), this, SIGNAL(configChanged()) );
 
-//     box->addSpacing( 5 );
+    box->addSpacing( 5 );
 
     QHBoxLayout *createActionsMenuBox = new QHBoxLayout( 0 );
     box->addLayout( createActionsMenuBox );
@@ -143,16 +141,6 @@ ConfigGeneralPage::ConfigGeneralPage( Config *_config, QWidget *parent )
     createActionsMenuBox->addWidget( cCreateActionsMenu );
     connect( cCreateActionsMenu, SIGNAL(toggled(bool)), this, SIGNAL(configChanged()) );
 
-    box->addSpacing( 5 );
-
-    QHBoxLayout *writeLogFilesBox = new QHBoxLayout( 0 );
-    box->addLayout( writeLogFilesBox );
-    cWriteLogFiles = new QCheckBox( i18n("Write log files to disc"), this );
-    cWriteLogFiles->setToolTip( i18n("Write log files to the hard drive while converting.\nThis can be useful if a crash occurs and you can't access the log file using the log viewer.\nLog files will be written to %1",KStandardDirs::locateLocal("data","soundkonverter/log/")) );
-    cWriteLogFiles->setChecked( config->data.general.writeLogFiles );
-    writeLogFilesBox->addWidget( cWriteLogFiles );
-    connect( cWriteLogFiles, SIGNAL(toggled(bool)), this, SIGNAL(configChanged()) );
-
     box->addSpacing( 20 );
 
     QHBoxLayout *replayGainGroupingBox = new QHBoxLayout( 0 );
@@ -184,7 +172,6 @@ void ConfigGeneralPage::resetDefaults()
     iNumFiles->setValue( ( processors.count() > 0 ) ? processors.count() : 1 );
     cWaitForAlbumGain->setChecked( true );
     cCreateActionsMenu->setChecked( true );
-    cWriteLogFiles->setChecked( false );
     cReplayGainGrouping->setCurrentIndex( 0 );
 
     emit configChanged( true );
@@ -200,7 +187,6 @@ void ConfigGeneralPage::saveSettings()
     config->data.general.numFiles = iNumFiles->value();
     config->data.general.waitForAlbumGain = cWaitForAlbumGain->isChecked();
     config->data.general.createActionsMenu = cCreateActionsMenu->isChecked();
-    config->data.general.writeLogFiles = cWriteLogFiles->isChecked();
     config->data.general.replayGainGrouping = (Config::Data::General::ReplayGainGrouping)cReplayGainGrouping->currentIndex();
 }
 
