@@ -32,11 +32,11 @@ public:
     int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output );
-    
+
     ConversionOptions *conversionOptionsFromXml( QDomElement conversionOptions );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( lame, soundkonverter_codec_lame );
+K_EXPORT_SOUNDKONVERTER_CODEC( lame, soundkonverter_codec_lame )
 
 
 #endif // _SOUNDKONVERTER_CODEC_LAME_H_
