@@ -38,7 +38,7 @@ private:
 
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( mplayer, soundkonverter_codec_mplayer );
+K_EXPORT_SOUNDKONVERTER_CODEC( mplayer, soundkonverter_codec_mplayer )
 
 
 #endif // SOUNDKONVERTER_CODEC_MPLAYER_H
