@@ -20,12 +20,12 @@ public:
     QString name();
 
     QList<ConversionPipeTrunk> codecTable();
-    
+
     bool isConfigSupported( ActionType action, const QString& codecName );
     void showConfigDialog( ActionType action, const QString& codecName, QWidget *parent );
     bool hasInfo();
     void showInfo( QWidget *parent );
-    
+
     QWidget *newCodecWidget();
 
     int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
@@ -33,7 +33,7 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( shorten, soundkonverter_codec_shorten );
+K_EXPORT_SOUNDKONVERTER_CODEC( shorten, soundkonverter_codec_shorten )
 
 
 #endif // _SOUNDKONVERTER_CODEC_SHORTEN_H_
